#
# spec file for package archivemount
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           archivemount
Version:        0.8.4
Release:        5.5
Summary:        Mounts an archive for access as a file system
License:        LGPL-2.1+ and BSD-2-Clause
Group:          Productivity/Archiving/Compression
Url:            http://www.cybernoia.de/software/archivemount/
Source:         http://www.cybernoia.de/software/archivemount/%{name}-%{version}.tar.gz
Patch0:         archivemount-%{version}.dif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fuse-devel
BuildRequires:  libarchive-devel
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Archivemount is a piece of glue code between libarchive (http://code.google.com/p/libarchive/) and FUSE
(http://fuse.sourceforge.net). It can be used to mount a (possibly compressed) archive (as in .tar.gz or
.tar.bz2) and use it like an ordinary filesystem.

%prep
%setup -q
%patch0

%build
    cflags ()
    {
	local flag=$1; shift
	local var=$1; shift
	test -n "${flag}" -a -n "${var}" || return
	case "${!var}" in
	*${flag}*) return
	esac
	set -o noclobber
	case "$flag" in
	-Wl,*)
	    if echo 'int main () { return 0; }' | \
               ${CC:-gcc} -Werror $flag -o /dev/null -xc - > /dev/null 2>&1 ; then
                eval $var=\${$var:+\$$var\ }$flag
	    fi
	    ;;
	*)
	    if ${CC:-gcc} -Werror $flag -S -o /dev/null -xc /dev/null > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	    if ${CXX:-g++} -Werror $flag -S -o /dev/null -xc++ /dev/null > /dev/null 2>&1 ; then
		eval $var=\${$var:+\$$var\ }$flag
	    fi
	esac
	set +o noclobber
    }
LDFLAGS=
cflags -Wl,-O2			LDFLAGS
cflags -Wl,--as-needed		LDFLAGS
cflags -Wl,--hash-size=8599	LDFLAGS

CFLAGS=
cflags -Wall			CFLAGS
cflags -Wextra			CFLAGS
cflags -pipe			CFLAGS
cflags -pthread			CFLAGS
cflags -pthreads		CFLAGS
cflags -mthread			CFLAGS
cflags -mthreads		CFLAGS
cflags -g2			CFLAGS
cflags -ggdb			CFLAGS
cflags -ftree-loop-im		CFLAGS
cflags -funswitch-loops		CFLAGS
cflags -fprefetch-loop-arrays	CFLAGS
cflags -fgraphite-identity	CFLAGS
cflags -ftree-loop-linear	CFLAGS
cflags -floop-flatten		CFLAGS
cflags -floop-parallelize-all	CFLAGS

autoreconf --force --install
%global optflags    %{optflags} -D_REENTRANT $LDFLAGS $CFLAGS
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%files
%defattr(-,root,root,0755)
%doc CHANGELOG README COPYING
%{_bindir}/archivemount
%{_mandir}/man1/archivemount.1.gz

%changelog
* Sun Mar 22 2015 mpluskal@suse.com
- Update to 0.8.4
  * added option -o formatraw for readonly support of the
    FormatRaw archive files supported by libarchive (kudos to Lee
    Leahu)
  * bugfix: do not do the fuse mount when the archive cannot be read
    (also kudos to Lee Leahu)
- Cleanup spec file with spec-cleaner
- Adapt patch to upstream changes
  * archivemount-0.8.3.dif to archivemount-0.8.4.dif
* Tue Dec 16 2014 p.drouand@gmail.com
- Update to version 0.8.3
  + do not call fuse_main anymore
  + force fuse into single-threaded mode due to libarchive not being
  thread-safe
- Adapt patch to upstream changes
  + archivemount-0.6.2.607cd0d.dif  > archivemount-0.8.3.dif
- Use download Url as source
- Remove redundant %%clean section
* Mon Oct 22 2012 werner@suse.de
- Update ot current github version 0.6.2.607cd0d (including BSD-2-Clause
  licensed header file uthash.h in source tar ball)
  + Based on version 0.6.2
  + Added annotations to some variables to indicate what lock should wrap
  + Refactored the trash to not be malloced each time it is used. Instead
  + Moved the lock creation up, to ensure the fd variable is always wrapp
  + Fixed a incorrect error check.
  + Added trace logging.
  + Changed the main locking mechansim to pthread_mutex_lock from pthread
  + Cleaned up some unused variables.
  + Cleaned up some comments used during benchmarking.
  + Fixed some minor error handling conditions, spotted by the awesome cl
  + Added some brackets to avoid paranoid complier warnings.
  + Bumped the _XOPEN_SOURCE version so pthread_mutex_timedlock could be
  + Fixed the link to libarchive.
  + Changed the open operation to create a new private archive reader obj
  + Ensure st_blocks, st_blksize are set when returned from archive_entry
  + Use a full struct stat when running readdir.
  + Add missing return type. Most likely from a typo.
  + Ensure free_node() cleans up all children.
  + Changed the main data structure from a double link list, to a hash ta
  + Fixed log() lines that had more arguments than used in the format str
  + Store the basename of a file in the Node struct. This speeds up build
  + Store a pointer to the last child in a directory. This makes insertin
  + Moved archive_entry_new into init_node. This again simplifies the cod
  + Rearranged the build_tree code to avoid a call to archive_entry_clone
  + Added a new free_node function to simplify freeing nodes.
  + Changed init_node to malloc a NODE and return it. This simplied the c
* Tue May 15 2012 werner@suse.de
- Add -pthread to the gcc command line
* Mon May  7 2012 werner@suse.de
- Enforce usage of reentrant versions of libc functions
- Fix off by one error by providing enough room for the ascii zero
  as well as for the new slash
- Avoid crash even if str(r)chr does not find a slash
* Thu Dec  8 2011 cfarrell@suse.com
- license update: LGPL-2.1+
  Package is LGPL-2.1+ according to the COPYING file. Use SPDX format
* Tue Dec  6 2011 werner@suse.de
- Initial package archivemount for openSUSE
